@@ -26,30 +26,29 @@ def activate_venv(path):
 
     # set current directory
     os.chdir(path)
-    print("🔨 setting up your virutal environment")
-    env = os.system("python -m venv env")
-    parent = os.getcwd()
-    project_path = path
+    print("🔨🔨 setting up your virutal environment")
+    os.system("python -m venv venv")
+    os.getcwd()
 
     env_activate_script = ""
     if OS == "Windows":
         env_activate_script = "Scripts"
 
     activate_file = os.path.join(path, "env", env_activate_script, "activate")
-    print("✏️ downloading packages")
+    print("🔧🔧 downloading packages")
     os.system(f"{activate_file} && pip install -r requirements.txt")
 
 
 @app.command("")
-def main(template_name):
+def start(template_name):
     template_path = get_template_path(template_name)
     path = cookiecutter(template_path)
-    print("🔨 setting up your project")
 
     activate_venv(path)
-    print("💥 your DRF project is ready!")
+    print("🎉🎉 your DRF project is ready! 🚀🚀")
     folder_name = pathlib.PurePath(path)
+    
     if OS == "Windows":
-        activate_file = os.path.join(path, "env", "Scripts", "activate")
-        print(f"cd {folder_name.name} && {activate_file}")
+        activate_file = os.path.join("env", "Scripts", "activate")
+        print(f"cd {folder_name.name}; {activate_file}")
 
